==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/NPCAutoPickItemGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal;

import cc.thonly.reverie_dreams.entity.npc.NPCRoleEntityImpl;
import java.util.List;
import net.minecraft.class_1352;
import net.minecraft.class_1542;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_238;

public class NPCAutoPickItemGoal extends class_1352 {

    private final NPCRoleEntityImpl role;
    private int ticks = 20;

    public NPCAutoPickItemGoal(NPCRoleEntityImpl role) {
        this.role = role;
    }

    @Override
    public boolean method_38846() {
        return true;
    }

    @Override
    public void method_6268() {
        super.method_6268();
        this.ticks--;
        if (this.ticks <= 0) {
            this.ticks = 20;
            class_1937 world = this.role.method_37908();
            class_2338 blockPos = this.role.method_24515();
            double radius = 4.5;
            class_238 box = new class_238(
                    blockPos.method_10263() - radius, blockPos.method_10264() - radius, blockPos.method_10260() - radius,
                    blockPos.method_10263() + radius, blockPos.method_10264() + radius, blockPos.method_10260() + radius
            );
            List<class_1542> nearbyItems = world.method_8390(class_1542.class, box, entity -> !entity.method_6977());
            if (!nearbyItems.isEmpty()) {
                class_1542 target = nearbyItems.getFirst();
                this.role.method_5942().method_6335(target, 1.2);
            }
        }
    }

    @Override
    public boolean method_6264() {
        return this.role.isAutoPick();
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/ai/goal/NPCAutoPickItemGoal.java <==
package cc.thonly.reverie_dreams.entity.ai.goal;

import cc.thonly.reverie_dreams.entity.npc.NPCRoleEntity;
import java.util.List;
import net.minecraft.class_1352;
import net.minecraft.class_1542;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_238;

public class NPCAutoPickItemGoal extends class_1352 {

    private final NPCRoleEntity role;
    private int ticks = 20;

    public NPCAutoPickItemGoal(NPCRoleEntity role) {
        this.role = role;
    }

    @Override
    public boolean method_38846() {
        return true;
    }

    @Override
    public void method_6268() {
        super.method_6268();
        this.ticks--;
        if (this.ticks <= 0) {
            this.ticks = 20;
            class_1937 world = this.role.method_37908();
            class_2338 blockPos = this.role.method_24515();
            double radius = 4.5;
            class_238 box = new class_238(
                    blockPos.method_10263() - radius, blockPos.method_10264() - radius, blockPos.method_10260() - radius,
                    blockPos.method_10263() + radius, blockPos.method_10264() + radius, blockPos.method_10260() + radius
            );
            List<class_1542> nearbyItems = world.method_8390(class_1542.class, box, entity -> !entity.method_6977());
            if (!nearbyItems.isEmpty()) {
                class_1542 target = nearbyItems.getFirst();
                this.role.method_5942().method_6335(target, 1.2);
            }
        }
    }

    @Override
    public boolean method_6264() {
        return this.role.isAutoPick();
    }
}
